@@ -38,14 +38,12 @@ import warnings
 import numpy as np
 # import ap_test
 try:
-    from bin import epics_fetch, get_dust, m4l, telescope_status
+    import get_dust
+    import m4l
+    import telescope_status
 except ImportError as e:
     try:
-        import epics_fetch
-        import get_dust
-        import m4l
-        import telescope_status
-
+        from bin import get_dust, m4l, telescope_status
     except ImportError as e:
         raise ImportError('Please add ObserverTools/bin to your PYTHONPATH:'
                           '\n    {}'.format(e))
@@ -66,7 +64,7 @@ except ImportError as e:
         import boss_data
         import log_support
     except ImportError as e:
-        raise ImportError('Please add ObserverTools/python to your PYTHONPATH:'
+        raise ImportError('Please add ObserverTools/sdssobstools to your PYTHONPATH:'
                           '\n    {}'.format(e))
 
 if sys.version_info.major < 3:
@@ -77,7 +75,7 @@ warnings.filterwarnings('ignore', category=UserWarning, append=True)
 # For numpy boolean arrays
 warnings.filterwarnings('ignore', category=FutureWarning, append=True)
 
-__version__ = '3.7.3'
+__version__ = '3.7.4'
 
 ap_dir = sdss_paths.ap_archive
 b_dir = sdss_paths.boss
@@ -146,7 +144,6 @@ class Logging:
                           'cAPSummary': [],
                           'cBSummary': []}
         self.test_procs = []
-        self.telemetry = epics_fetch.telemetry
         # Commented out to test the apogee_data.APOGEERaw.ap_test method
         # self.ap_tester = ap_test.ApogeeFlat(
         #     Path(__file__).absolute().parent.parent
@@ -262,7 +259,8 @@ class Logging:
         if self.args.apogee:
             print('Reading APOGEE Data ({})'.format(len(self.ap_images)))
             for image in tqdm(self.ap_images):
-                # print(image)
+                if self.args.verbose:
+                    print(image.name)
                 img = apogee_data.APOGEERaw(image, self.args, 1)
                 # img.parse_layer(1)
                 if img.lead is None:  # If the first exposure is still
@@ -299,7 +297,10 @@ class Logging:
                     self.data['cPlate'].append(img.plate_id)
                     self.data['cCart'].append(img.cart_id)
                     self.data['cTime'].append(img.isot)
-                    self.data['cLead'].append(img.lead)
+                    try:
+                        self.data['cLead'].append(img.lead)
+                    except AttributeError:
+                        self.data["cLead"].append("")
                 else:
                     i = self.data['cCart'].index(img.cart_id)
                     if img.isot < self.data['cTime'][i]:
@@ -356,7 +357,10 @@ class Logging:
                 if img.cart_id not in self.data['cCart']:
                     self.data['cCart'].append(img.cart_id)
                     self.data['cPlate'].append(img.plate_id)
-                    self.data['cLead'].append(img.lead)
+                    try:
+                        self.data['cLead'].append(img.lead)
+                    except AttributeError:
+                        self.data["cLead"].append("")    
                     self.data['cTime'].append(img.isot)
                 else:
                     i = self.data['cCart'].index(img.cart_id)
@@ -381,31 +385,31 @@ class Logging:
                 self.b_data['iHart'].append(img.hartmann)
                 self.b_data['iPlate'].append(img.plate_id)
 
-                if img.hartmann == 'Left':
-                    # Note that times are sent in UTC and received in local, yet
-                    # those times are marked as UTC
-                    tstart = Time(img.isot).datetime
-                    tend = (Time(img.isot) + 5 / 24 / 60).datetime
-                    hart = self.telemetry.get([
-                        '25m:hartmann:r1PistonMove',
-                        # '25m:hartmann:r2PistonMove',
-                        '25m:hartmann:b1RingMove',
-                        # '25m:hartmann:b2RingMove',
-                        '25m:hartmann:sp1AverageMove',
-                        # '25m:hartmann:sp2AverageMove',
-                        '25m:hartmann:sp1Residuals:steps',
-                        '25m:hartmann:sp1Residuals:deg',
-                        # '25m:hartmann:sp2Residuals:deg',
-                        '25m:boss:sp1Temp:median',
-                        # '25m:boss:sp2Temp:median',
-                        # '25m:hartmann:sp2Residuals:steps'
-                    ],
-                        start=tstart,
-                        end=tend,
-                        interpolation='raw', scan_archives=False)
+                # if img.hartmann == 'Left' and self.telemetry:
+                #     # Note that times are sent in UTC and received in local, yet
+                #     # those times are marked as UTC
+                #     tstart = Time(img.isot).datetime
+                #     tend = (Time(img.isot) + 5 / 24 / 60).datetime
+                #     hart = self.telemetry.get([
+                #         '25m:hartmann:r1PistonMove',
+                #         # '25m:hartmann:r2PistonMove',
+                #         '25m:hartmann:b1RingMove',
+                #         # '25m:hartmann:b2RingMove',
+                #         '25m:hartmann:sp1AverageMove',
+                #         # '25m:hartmann:sp2AverageMove',
+                #         '25m:hartmann:sp1Residuals:steps',
+                #         '25m:hartmann:sp1Residuals:deg',
+                #         # '25m:hartmann:sp2Residuals:deg',
+                #         '25m:boss:sp1Temp:median',
+                #         # '25m:boss:sp2Temp:median',
+                #         # '25m:hartmann:sp2Residuals:steps'
+                #     ],
+                #         start=tstart,
+                #         end=tend,
+                #         interpolation='raw', scan_archives=False)
 
-                    self.b_data['hHart'].append(hart)
-                    self.b_data['hTime'].append(img.isot)
+                #     self.b_data['hHart'].append(hart)
+                #     self.b_data['hTime'].append(img.isot)
                 sos_files = []
                 # img_mjd = int(Time(img.isot).mjd)
                 # All boss exposures write as splog, but manga writes different
@@ -816,10 +820,10 @@ class Logging:
                 self.ap_data['iDetector'][self.morning_filter],
                 self.ap_data['iSeeing'][self.morning_filter]
             ):
-                print('{:<5.0f} {:>8} {:>2.0f}-{:<5.0f} {:<8.0f} {:<12} {:<4}'
+                print('{:<5.0f} {:>8} {:>5.0f} {:<8.0f} {:<12} {:<4}'
                       ' {:>5}'
                       ' {:<5}'
-                      ' {:>6.1f}'.format(int(mjd), iso[11:19], cart, plate,
+                      ' {:>6.1f}'.format(int(mjd), iso[11:19], cart,
                                          exp_id, exp_type,
                                          dith, nread, detectors, see))
 
@@ -835,12 +839,19 @@ class Logging:
                 self.ap_data['iDetector'],
                 self.ap_data['iSeeing']
             ):
-                print('{:<5.0f} {:>8} {:>2.0f}-{:<5.0f} {:<8.0f} {:<12} {:<4}'
+                # print('{:<5.0f} {:>8} {:>2.0f}-{:<5.0f} {:<8.0f} {:<12} {:<4}'
+                #       ' {:>6}'
+                #       ' {:<8}'
+                #       ' {:>6.1f}'.format(int(mjd), iso[11:19], cart, plate,
+                #                          exp_id, exp_type,
+                #                          dith, nread, detectors, see))
+                print('{:<5.0f} {:>8} {:>5.0f} {:<8.0f} {:<12} {:<4}'
                       ' {:>6}'
                       ' {:<8}'
-                      ' {:>6.1f}'.format(int(mjd), iso[11:19], cart, plate,
+                      ' {:>6.1f}'.format(int(mjd), iso[11:19], cart,
                                          exp_id, exp_type,
                                          dith, nread, detectors, see))
+
         # Usually, there are 4 ThAr and 4 UNe arcs in a night, and they're
         # assumed to be alternating ThAr UNe ThAr UNe. When you grab every
         # other, you'll have only one type, that's the first slicing, and the
@@ -876,6 +887,8 @@ class Logging:
         print('\n')
 
     def log_support(self):
+        if not log_support.has_epics:
+            return
         start = Time(self.args.sjd, format='mjd')
         end = Time(self.args.sjd + 1, format='mjd')
         tel = log_support.LogSupport(start, end, self.args)
